;
; AutoIt Version: 3.0
; Language:       English
; Platform:       Win9x/NT
; Author:         Michael W. Bayley
;
; Script Function:
;  Convert MultiRun 1.1 data file to 1.2   

#include "MultiRunDefs.au3"

;
; Global values
;

; Title Information
$TitleBar = "MultiRun Verion 1.1 to 1.2Converter, (c)2007 Michael W. Bayley"
$Errors = 0

; Ini/Mrn Option Values
$IniFile = ""
$SectionID = 0

; Program ID
$Tag = ""
$Major = 0
$Minor = 0

;
; Main Code
;
; Entry:       <None>
; Return:      0 - No errors
;              1 - Fatal error encountered
; Procedure:   1. If too many command line parameters then message & exit.
;              2. Error if mrn file not found.
;              3. Verify it is a MultiRun profile, error if not.
;              4. Update version information.
;              5. Exit all done.
;

; 1. If too many command line parameters then message & exit.
If $CmdLine[0] > 1 Then
   $msg = "This program upgrades your MultiRun data file from version 1.1 to version 1.2." & @CRLF
   $msg = $msg & "This is required for the new version of MultiRun to recognize the profile file.  If" & @CRLF
   $msg = $msg & "you run the program with no command line arguments then the default profile" & @CRLF
   $msg = $msg & "will be used.  Otherwise you can specify a single profile on the command line." & @CRLF & @CRLF
   $msg = $msg & "In all instances the profile file msut exist in the same directory as the program." & @CRLF & @CRLF
   MsgBox(0, $TitleBar, $msg)
   Exit(1)
ElseIf $CmdLine[0] == 1 Then
   $IniFile = @ScriptDir
   If StringRight($IniFile, 1) == "\" Then
      $IniFile = $IniFile & $CmdLine[1]
   Else
      $IniFile = $IniFile & "\" & $CmdLine[1]
   EndIf
Else
    $IniFile = @ScriptDir
   If StringRight($IniFile, 1) == "\" Then
      $IniFile = $IniFile & $IniFileName
   Else
      $IniFile = $IniFile & "\" & $IniFileName
   EndIf
EndIf


; 2. Error if mrn file not found.
If FileExists($IniFile) <> 1 Then
   MsgBox(0, $TitleBar, "Error - Profile " & $IniFile & " not found!")
   Exit(1)   
EndIf


; 3. Verify it is a MultiRun profile, error if not.
$SectionID = Number(IniRead($IniFile, $IniSection, $IniSectionID, 0))
$Tag = IniRead($IniFile, $IniSection, $IniProgramID, "")
$Major = Number(IniRead($IniFile, $IniSection, $IniMajor, $Major))
$Minor = Number(IniRead($IniFile, $IniSection, $IniMinor, $Minor))

If $Tag <> $ProgramID Then
	MsgBox(0, $TitleBar, "Error - '" & $IniFile & "' is not a valid MultiRun file.")
	Exit(1)
EndIf

If $Major == $ProgramMajor AND $Minor == $ProgramMinor Then
	MsgBox(0, $TitleBar, "'" & $IniFile & "' appears to have already been upgraded.")
	Exit(0)
ElseIf $Major <> $ProgramMajor OR $Minor <> $ProgramMinor - 1 Then
	MsgBox(0, $TitleBar, "Error - '" & $IniFile & "' is a different version.")
	Exit(1)
EndIf

If $SectionID <> $IniMainSectionID Then
	If MsgBox(260, $TitleBar, "Error - '" & $IniFile & "' appears to be corrupt. Attempt to fix it?") <> 6 Then
		Exit(1)
	EndIf
	
	If FileWrite($IniFile, $IniSection, $IniSectionID, $IniMainSectionID) <> 1 Then
		MsgBox(0, $TitleBar, "Error - Failure attempting to repair '" & $IniFile & "'")
		Exit(1)
	EndIf
EndIf


; 4, Fix existing keys and sections.
If IniWrite($IniFile, $IniSection, $IniMajor, $ProgramMajor) <> 1 Then
   MsgBox(0, $TitleBar, "Error - Failure writing to profile " & $IniFile & "!")
   $Errors += 1
EndIf

If IniWrite($IniFile, $IniSection, $IniMinor, $ProgramMinor) <> 1 Then
   MsgBox(0, $TitleBar, "Error - Failure writing to profile " & $IniFile & "!")
   $Errors += 1
EndIf


; 5. Exit all done.
MsgBox(0, $TitleBar, "Process Complete!  Errors = " & $Errors & @CRLF)
If $Errors Then Exit(1)
Exit(0)

